summaryrefslogtreecommitdiffstats
path: root/kipi-plugins/wallpaper
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commitea3848d71d9559414d14d0a8b8bb1ebb684f46c2 (patch)
tree859d20a007be94df4bf0b78cdf3720bfee903892 /kipi-plugins/wallpaper
parent94ec53c96c3d5dc4a427e7dc4bbaa863add5cfa4 (diff)
downloadkipi-plugins-ea3848d71d9559414d14d0a8b8bb1ebb684f46c2.tar.gz
kipi-plugins-ea3848d71d9559414d14d0a8b8bb1ebb684f46c2.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/libraries/kipi-plugins@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kipi-plugins/wallpaper')
-rw-r--r--kipi-plugins/wallpaper/plugin_wallpaper.cpp10
-rw-r--r--kipi-plugins/wallpaper/plugin_wallpaper.h2
2 files changed, 6 insertions, 6 deletions
diff --git a/kipi-plugins/wallpaper/plugin_wallpaper.h b/kipi-plugins/wallpaper/plugin_wallpaper.h
index 6be59b3..03db2fc 100644
--- a/kipi-plugins/wallpaper/plugin_wallpaper.h
+++ b/kipi-plugins/wallpaper/plugin_wallpaper.h
@@ -45,7 +45,7 @@
public:
- Plugin_WallPaper(TQObject *tqparent,
+ Plugin_WallPaper(TQObject *parent,
const char* name,
const TQStringList &args);
virtual KIPI::Category category( KAction* action ) const;
diff --git a/kipi-plugins/wallpaper/plugin_wallpaper.cpp b/kipi-plugins/wallpaper/plugin_wallpaper.cpp
index 1a4da77..90efa9e 100644
--- a/kipi-plugins/wallpaper/plugin_wallpaper.cpp
+++ b/kipi-plugins/wallpaper/plugin_wallpaper.cpp
@@ -56,8 +56,8 @@ K_EXPORT_COMPONENT_FACTORY( kipiplugin_wallpaper,
/////////////////////////////////////////////////////////////////////////////////////////////////////
- Plugin_WallPaper::Plugin_WallPaper(TQObject *tqparent, const char*, const TQStringList&)
- : KIPI::Plugin( Factory::instance(), tqparent, "WallPaper")
+ Plugin_WallPaper::Plugin_WallPaper(TQObject *parent, const char*, const TQStringList&)
+ : KIPI::Plugin( Factory::instance(), parent, "WallPaper")
{
kdDebug( 51001 ) << "Plugin_WallPaper plugin loaded" << endl;
}
@@ -132,7 +132,7 @@ void Plugin_WallPaper::setup( TQWidget* widget )
addAction( m_action_Background );
- KIPI::Interface* interface = dynamic_cast<KIPI::Interface*>( tqparent() );
+ KIPI::Interface* interface = dynamic_cast<KIPI::Interface*>( parent() );
if ( !interface )
{
@@ -217,7 +217,7 @@ void Plugin_WallPaper::setWallpaper(int tqlayout)
if (tqlayout>SCALE_AND_CROP || tqlayout < CENTER)
return;
- KIPI::Interface* interface = dynamic_cast<KIPI::Interface*>( tqparent() );
+ KIPI::Interface* interface = dynamic_cast<KIPI::Interface*>( parent() );
if ( !interface )
{
@@ -237,7 +237,7 @@ void Plugin_WallPaper::setWallpaper(int tqlayout)
}
else
{
// PENDING We need a way to get a tqparent widget
// Sun, 06 Jun 2004 - Aur�ien
KMessageBox::information( TQT_TQWIDGET(kapp->activeWindow()), i18n(
@@ -237,7 +237,7 @@ void Plugin_WallPaper::setWallpaper(int tqlayout)
else
{
- // PENDING We need a way to get a tqparent widget
+ // PENDING We need a way to get a parent widget
// Sun, 06 Jun 2004 - Aur�ien
KMessageBox::information( TQT_TQWIDGET(kapp->activeWindow()), i18n(